@@ -867,6 +867,7 @@ class HostedBackend(Backend):
                                 dict['mode'], dict['create_user_name'], dict['create_time'], dict['create_user_id'])
 
     @with_api_exceptions_handler
+    @require_model
     def download_model_version_asset(self, repo_id, path, destination=''):
         if not destination:
             destination = os.getcwd()
@@ -883,29 +884,39 @@ class HostedBackend(Backend):
             s3path = self._get_repo_s3path(repo_id)
             if s3path is None:
                 return 's3path不存在'
+            s3path = s3path.split('s3://')
+            s3path = '/' + s3path[1] + '/'
             with Pool(5) as pool:
                 if '.' not in path:
-                    resultinfo, dir = self.list_dir_model_artifacts(repo_id, path, [], [])
+                    resultinfo, dir = self._list_dir_model_artifacts(repo_id, path, [], [])
+                    if resultinfo == []:
+                        raise Exception(f"当前目录下无文件，请检查目录参数{path}")
                     for i in dir:
                         if i[0] != '/':
                             continue
-                        if not os.path.exists(destination + i):
-                            os.makedirs(destination + i)
+                        if path[-1] != '/':
+                            if not os.path.exists(destination + i):
+                                os.makedirs(destination + i)
                     for result in resultinfo:
-                        result_path = result.rsplit('/', 1)
-                        des_path = result_path[0]
-                        result_path = result_path[-1]
-                        file_path = minio_path + s3path + '/' + result_path
-                        urls.append((file_path, destination + '/' + des_path, result_path))
+                        file_path = minio_path + s3path + result
+                        file_name = result.split('/')
+                        des_path = file_name[0]
+                        file_name = file_name[-1]
+                        if '/' in result:
+                            urls.append((file_path, destination + '/' + des_path, file_name))
+                        else:
+                            urls.append((file_path, destination, file_name))
                 else:
+                    path_status = self._check_file_status(repo_id, path)
+                    if path_status is False:
+                        raise Exception(f"当前目录下不存在文件，请检查目录参数:{path}")
                     if '/' in path:
-                        path = path.rsplit('/', 1)
-                        des_path = path[0]
-                        path = path[-1]
+                        split_path = path.split('/')
+                        file_name = split_path[-1]
                         file_path = minio_path + s3path + path
-                        urls.append((file_path, destination + '/' + des_path, path))
+                        urls.append((file_path, destination, file_name))
                     else:
-                        file_path = path + s3path + path
+                        file_path = minio_path + s3path + path
                         urls.append((file_path, destination, path))
                 pool.map(self._url_download, urls)
                 pool.close()
@@ -981,6 +992,22 @@ class HostedBackend(Backend):
                 result.append(d['path'])
         return list(set(result)), list(set(dir))
 
+
+    @with_api_exceptions_handler
+    def _check_file_status(self, repo_id, path):
+        """
+        递归获取所有的文件，文件夹
+        :param repo_id:
+        :path 文件路径
+        :return: 返回文件，图片数据集文件，文件夹列表
+        """
+        res = self._session.get(url=f'{self.api_address}/training/run/{repo_id}/artifacts/status?file={path}')
+        if res.json()["message"]:
+            raise Exception(res.json()["message"])
+        return res.json()['data']
+
+
+
     @with_api_exceptions_handler
     @require_model
     def _get_repo_s3path(self, repo_id):
