@@ -21,8 +21,8 @@ API_MODEL= 'WAVELETAI_MODEL'
 
 API_PROJ = 'WAVELETAI_PROJ'
 
-"""单次请求最大值"""
+"""单次请求最大值 1kb"""
 CHUNK_SIZE = 1024
 
-"""超过5M的内容显示进度"""
+"""超过1M的内容显示进度"""
 WARN_SIZE = 1024 * 1024 * 1
